@@ -299,6 +299,7 @@ namespace YODA {
     /// @name Type reduction
     /// @{
 
+    /// @brief Make an inert estimate with the value and error of the counter
     inline Estimate0D mkEstimate(const std::string& path = "", const std::string& source = "") const {
       Estimate0D rtn;
       for (const std::string& a : annotations()) {
@@ -313,6 +314,28 @@ namespace YODA {
       return rtn;
     }
 
+    /// @brief Make an inert estimate with the value and error of the counter
+    ///
+    /// @note The uncertainty on the effective entries is currently set to zero,
+    /// as we don't have a formula for it! So the source arg (for uniformity)
+    /// is currently ignored.
+    inline Estimate0D mkEffNumEntries(const std::string& path = "", const std::string& /* source */ = "") const {
+      Estimate0D rtn;
+      for (const std::string& a : annotations()) {
+        if (a != "Type")  rtn.setAnnotation(a, annotation(a));
+      }
+      rtn.setAnnotation("Path", path);
+
+      rtn.setVal(effNumEntries());
+      /// @todo What's the uncertainty on Neff?
+      // if (numEntries()) { // only set uncertainty for filled Dbns
+      //   rtn.setErr(err(), source);
+      // }
+
+      return rtn;
+    }
+
+    /// @brief Make an inert scatter with the value and error of the counter
     inline Scatter1D mkScatter(const std::string& path = "") const {
       Scatter1D rtn;
       for (const std::string& a : annotations()) {
