@@ -10,12 +10,14 @@
 #include "YODA/Utils/DbnUtils.h"
 #include "YODA/Utils/MathUtils.h"
 #include "YODA/Utils/MetaUtils.h"
+#include "YODA/Utils/StatsUtils.h"
 #include <cmath>
 #include <string>
 #include <array>
 
 namespace YODA {
 
+
   /// @brief some utility methods
   ///
   /// @note Anonymous namespace to limit visibility to this file
@@ -34,14 +36,14 @@ namespace YODA {
         return {};
     }
 
-    /// base step to concatenate two sequences
+    /// Base step to concatenate two sequences
     template<typename INT, INT... s, INT... t>
     constexpr std::integer_sequence<INT,s...,t...>
     concat_sequences(std::integer_sequence<INT, s...>, std::integer_sequence<INT, t...>){
         return {};
     }
 
-    /// recursion step to concatenate multuple sequences
+    /// Recursion step to concatenate multiple sequences
     template<typename INT, INT... s, INT... t, class... R>
     constexpr auto
     concat_sequences(std::integer_sequence<INT, s...>, std::integer_sequence<INT, t...>, R...) {
@@ -91,7 +93,7 @@ namespace YODA {
     using DataSize = std::integral_constant<size_t, 1 + 2*(N+1) + (N*(N-1)/2)>;
 
     /// @name Constructors
-    //@{
+    /// @{
 
     /// Default constructor of a new distribution.
     DbnBase() { reset(); }
@@ -134,11 +136,11 @@ namespace YODA {
     /// Sets all the parameters using the ones provided from an existing DbnBase.
     DbnBase& operator = (DbnBase&&) = default;
 
-    //@}
+    /// @}
 
 
     /// @name Modifiers
-    //@{
+    /// @{
 
 
     /// @brief Contribute a sample at @a val (from an array) with weight @a weight.
@@ -267,43 +269,69 @@ namespace YODA {
     }
 
 
-    //@}
+    /// @}
 
     public:
 
 
     /// @name Distribution statistics
-    //@{
+    /// @{
 
     /// The absolute error on sumW
-    double errW() const;
+    double errW() const {
+      return sqrt(sumW2(0));
+    }
 
     /// The relative error on sumW
-    double relErrW() const;
+    double relErrW() const {
+      if (effNumEntries() == 0) {
+        return std::numeric_limits<double>::quiet_NaN();
+      }
+      return errW()/sumW(0);
+    }
 
     /// Weighted mean, \f$ \bar{x} \f$, of distribution.
-    double mean(const size_t i) const;
+    template<size_t dim = N, typename = std::enable_if_t<(dim >= 1)>>
+    double mean(const size_t i) const {
+      return YODA::mean(sumW(i), sumW(0));
+    }
 
     /// Weighted variance, \f$ \sigma^2 \f$, of distribution.
-    double variance(const size_t i) const;
+    template<size_t dim = N, typename = std::enable_if_t<(dim >= 1)>>
+    double variance(const size_t i) const {
+      return YODA::variance(sumW(i), sumW(0), sumW2(i), sumW2(0));
+    }
 
     /// Weighted standard deviation, \f$ \sigma \f$, of distribution.
+    template<size_t dim = N, typename = std::enable_if_t<(dim >= 1)>>
     double stdDev(const size_t i) const { return std::sqrt(variance(i)); }
 
     /// Weighted standard error on the mean, \f$ \sim \sigma/\sqrt{N-1} \f$, of distribution.
-    double stdErr(const size_t i) const;
+    template<size_t dim = N, typename = std::enable_if_t<(dim >= 1)>>
+    double stdErr(const size_t i) const {
+      return YODA::stdErr(sumW(i), sumW(0), sumW2(i), sumW2(0));
+    }
 
     /// Relative weighted standard error on the mean, \f$ \sim \sigma/\sqrt{N-1} \f$, of distribution.
-    double relStdErr(const size_t i) const;
+    template<size_t dim = N, typename = std::enable_if_t<(dim >= 1)>>
+    double relStdErr(const size_t i) const {
+      if (effNumEntries() == 0) {
+        return std::numeric_limits<double>::quiet_NaN();
+      }
+      return stdErr(i) / mean(i);
+    }
 
     /// Weighted RMS, \f$ \sqrt{ \sum{w x^2}/\sum{w} } \f$, of distribution.
-    double RMS(const size_t i) const;
+    template<size_t dim = N, typename = std::enable_if_t<(dim >= 1)>>
+    double RMS(const size_t i) const {
+      return YODA::RMS(sumW2(i), sumW(0), sumW2());
+    }
 
-    //@}
+    /// @}
 
 
     /// @name Raw distribution running sums
-    //@{
+    /// @{
 
     /// Number of entries (number of times @c fill was called, ignoring weights)
     double numEntries() const {
@@ -356,7 +384,7 @@ namespace YODA {
 
     size_t dim() const { return N; }
 
-    //@}
+    /// @}
 
     /// @name I/O
     /// @{
@@ -366,16 +394,16 @@ namespace YODA {
       std::string res ="";
       res += ("numEntries="+ std::to_string(_numEntries))  ;
       if (sumW()) {
-        res += (", Mean="+ std::to_string(mean(0)))  ;
-        res += (", RMS="+ std::to_string(RMS(0)))  ;
+        res += (", sumW="+ std::to_string(sumW()))  ;
+        res += (", errW="+ std::to_string(errW()))  ;
       }
       return res;
     }
 
-    //@}
+    /// @}
 
     /// @name Reduce operations
-    // @{
+    /// @{
 
     /// @brief Reduce operation that produces a lower-dimensional DbnBase
     /// keeping only the specified axes in the new DbnBase.
@@ -419,10 +447,10 @@ namespace YODA {
       return reduceTo(new_axes);
     }
 
-    // @}
+    /// @}
 
     /// @name MPI (de-)serialisation
-    //@{
+    /// @{
 
     size_t _lengthContent() const noexcept {
       return DataSize::value;
@@ -451,10 +479,10 @@ namespace YODA {
 
     }
 
-    // @}
+    /// @}
 
     /// @name Operators
-    //@{
+    /// @{
 
     /// Add two DbnBases
     DbnBase& operator += (const DbnBase& d);
@@ -468,12 +496,12 @@ namespace YODA {
     /// Subtract one DbnBase from another
     DbnBase& operator -= (DbnBase&& d);
 
-    //@}
+    /// @}
 
     private:
 
     /// @name Storage
-    //@{
+    /// @{
 
     double _numEntries;
 
@@ -486,10 +514,10 @@ namespace YODA {
     /// The 2nd order weighted "cross-term"
     std::array<double, N*(N-1)/2> _sumWcross;
 
-    //@}
+    /// @}
 
     /// @name Helper methods
-    //@{
+    /// @{
 
     /// @brief Expands values array
     template <size_t... I>
@@ -498,55 +526,10 @@ namespace YODA {
       fill(vals[I]..., weight, fraction);
     }
 
-    //@}
+    /// @}
   };
 
 
-  template <size_t N>
-  double DbnBase<N>::errW() const {
-    return sqrt(sumW2(0));
-  }
-
-  template <size_t N>
-  double DbnBase<N>::relErrW() const {
-    if (effNumEntries() == 0) {
-      return std::numeric_limits<double>::quiet_NaN();
-    }
-    return errW()/sumW(0);
-  }
-
-  template <size_t N>
-  double DbnBase<N>::mean(const size_t i) const {
-    return YODA::mean(sumW(i), sumW(0));
-  }
-
-
-  template <size_t N>
-  double DbnBase<N>::variance(const size_t i) const {
-    return YODA::variance(sumW(i), sumW(0), sumW2(i), sumW2(0));
-  }
-
-
-  template <size_t N>
-  double DbnBase<N>::stdErr(const size_t i) const {
-    return YODA::stdErr(sumW(i), sumW(0), sumW2(i), sumW2(0));
-  }
-
-
-  template <size_t N>
-  double DbnBase<N>::relStdErr(const size_t i) const {
-    if (effNumEntries() == 0) {
-      return std::numeric_limits<double>::quiet_NaN();
-    }
-    return stdErr(i) / mean(i);
-  }
-
-
-  template <size_t N>
-  double DbnBase<N>::RMS(const size_t i) const {
-    return YODA::RMS(sumW2(i), sumW(0), sumW2());
-  }
-
   template <size_t N>
   DbnBase<N>& DbnBase<N>::operator += (const DbnBase<N>& d) {
     _numEntries += d._numEntries;
