@@ -19,6 +19,7 @@
 
 namespace YODA {
 
+
   /// @brief An estimate in 0D
   ///
   /// This class linkes the Estimate class with
@@ -36,7 +37,7 @@ namespace YODA {
     using AnalysisObject::operator =;
 
     /// @name Constructors
-    //@{
+    /// @{
 
     /// @brief Nullary constructor for unique pointers etc.
     ///
@@ -88,11 +89,11 @@ namespace YODA {
       return new Estimate0D(*this);
     }
 
-    //@}
+    /// @}
 
 
     /// @name Operators
-    //@{
+    /// @{
 
     /// Copy assignment
     ///
@@ -157,7 +158,7 @@ namespace YODA {
       return subtract(std::move(toSubtract));
     }
 
-    //@}
+    /// @}
 
     /// @name Dimensions
     /// @{
@@ -165,19 +166,19 @@ namespace YODA {
     /// @brief Total dimension of this data object
     size_t dim() const noexcept { return 1; }
 
-    //@}
+    /// @}
 
     /// @name Modifiers
-    //@{
+    /// @{
 
     /// Reset the internal values
     void reset() noexcept {
       BaseT::reset();
     }
 
-    //@}
+    /// @}
 
-    // @brief Render information about this AO
+    /// @brief Render information about this AO
     void _renderYODA(std::ostream& os, const int width = 13) const noexcept {
 
       // Render error sources
@@ -223,7 +224,7 @@ namespace YODA {
       os << "\n";
     }
 
-    // @brief Render scatter-like information about this AO
+    /// @brief Render scatter-like information about this AO
     void _renderFLAT(std::ostream& os, const int width = 13) const noexcept {
       const Scatter1D tmp = mkScatter();
       tmp._renderYODA(os, width);
@@ -231,7 +232,7 @@ namespace YODA {
 
     #ifdef HAVE_HDF5
 
-    // @brief Extract error labels of this AO
+    /// @brief Extract error labels of this AO
     void _extractLabels(std::vector<std::string>& labels,
                         std::vector<size_t>& labelsizes) const noexcept {
       // append new set of keys
@@ -245,7 +246,7 @@ namespace YODA {
       labels.erase( std::unique(labels.begin(), labels.end()), labels.end() );
     }
 
-    // @brief Extract error breakdown of this AO into the map of @a edges
+    /// @brief Extract error breakdown of this AO into the map of @a edges
     void _extractEdges(std::map<std::string, EdgeHandlerBasePtr>& edges,
                        const std::vector<std::string>& labels) const noexcept {
 
@@ -287,7 +288,7 @@ namespace YODA {
     /// @}
 
     /// @name Type reductions
-    //@{
+    /// @{
 
     inline Scatter1D mkScatter(const std::string& path = "",
                                const std::string& pat_match = "") const noexcept {
@@ -298,8 +299,8 @@ namespace YODA {
       rtn.setAnnotation("Path", path);
 
       // Add the PointND
-      const double tot = fabs(totalErrPos(pat_match)); // use positive error component
-      rtn.addPoint( Point1D(val(), {tot, tot}) );
+      const std::pair<double,double> tot = totalErr(pat_match);
+      rtn.addPoint( Point1D(val(), {fabs(tot.first), tot.second}) );
 
       return rtn;
     }
@@ -318,7 +319,7 @@ namespace YODA {
       return rtn;
     }
 
-    //@}
+    /// @}
 
   };
 
@@ -338,7 +339,7 @@ namespace YODA {
 
 
   /// @name Global operators for Estimate0D objects
-  //@{
+  /// @{
 
   /// @brief Add two Estimate0D objects
   inline Estimate0D operator + (Estimate0D lhs, const Estimate0D& rhs) {
@@ -404,7 +405,7 @@ namespace YODA {
     return rtn;
   }
 
-  //@}
+  /// @}
 
 }
 
