@@ -10,6 +10,7 @@
 
 namespace YODA {
 
+
   /// @name Mixin of convenience methods using CRTP
   /// @{
 
@@ -47,18 +48,61 @@ namespace YODA {
       return static_cast<const Derived*>(this)->template widths<0>(includeOverflows);
     }
 
+    /// @brief All mins on X axis
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT>
+    std::enable_if_t<std::is_floating_point<T>::value, std::vector<T>>
+    xMins(const bool includeOverflows = false) const {
+      return static_cast<const Derived*>(this)->template mins<0>(includeOverflows);
+    }
+
+    /// @brief All maxs on X axis
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT>
+    std::enable_if_t<std::is_floating_point<T>::value, std::vector<T>>
+    xMaxs(const bool includeOverflows = false) const {
+      return static_cast<const Derived*>(this)->template maxs<0>(includeOverflows);
+    }
+
+    /// @brief All mids on X axis
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT>
+    std::enable_if_t<std::is_floating_point<T>::value, std::vector<T>>
+    xMids(const bool includeOverflows = false) const {
+      return static_cast<const Derived*>(this)->template mids<0>(includeOverflows);
+    }
+
+    /// @brief Merge every group of @a n bins, from start to end inclusive
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT, typename = std::enable_if_t<std::is_floating_point<T>::value>>
     void rebinXBy(unsigned int n, size_t begin=1, size_t end=UINT_MAX) {
       static_cast<Derived*>(this)->template rebinBy<0>(n, begin, end);
     }
 
+    /// @brief Rebin to the given list of bin edges
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT, typename = std::enable_if_t<std::is_floating_point<T>::value>>
     void rebinXTo(const std::vector<double>& newedges) {
       static_cast<Derived*>(this)->template rebinTo<0>(newedges);
     }
 
+    /// @brief Overloaded alias for rebinXBy
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT, typename = std::enable_if_t<std::is_floating_point<T>::value>>
     void rebinX(unsigned int n, size_t begin=1, size_t end=UINT_MAX) {
       static_cast<Derived*>(this)->template rebinBy<0>(n, begin, end);
     }
 
+    /// @brief Overloaded alias for rebinXTo
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT, typename = std::enable_if_t<std::is_floating_point<T>::value>>
     void rebinX(const std::vector<double>& newedges) {
       static_cast<Derived*>(this)->template rebinTo<0>(newedges);
     }
@@ -75,6 +119,11 @@ namespace YODA {
     /// @name Whole histo data
     /// @{
 
+    /// @brief List of mean values on X axis
+    std::vector<double> xMeans(const bool includeOverflows=true) const noexcept {
+      return static_cast<const Derived*>(this)->means(0, includeOverflows);
+    }
+
     /// @brief Calculate the mean on X axis
     double xMean(const bool includeOverflows=true) const noexcept {
       return static_cast<const Derived*>(this)->mean(0, includeOverflows);
@@ -138,18 +187,61 @@ namespace YODA {
       return static_cast<const Derived*>(this)->template widths<1>(includeOverflows);
     }
 
+    /// @brief All mins on Y axis
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT>
+    std::enable_if_t<std::is_floating_point<T>::value, std::vector<T>>
+    yMins(const bool includeOverflows = false) const {
+      return static_cast<const Derived*>(this)->template mins<1>(includeOverflows);
+    }
+
+    /// @brief All maxs on Y axis
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT>
+    std::enable_if_t<std::is_floating_point<T>::value, std::vector<T>>
+    yMaxs(const bool includeOverflows = false) const {
+      return static_cast<const Derived*>(this)->template maxs<1>(includeOverflows);
+    }
+
+    /// @brief All mids on Y axis
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT>
+    std::enable_if_t<std::is_floating_point<T>::value, std::vector<T>>
+    yMids(const bool includeOverflows = false) const {
+      return static_cast<const Derived*>(this)->template mids<1>(includeOverflows);
+    }
+
+    /// @brief Merge every group of @a n bins, from start to end inclusive
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT, typename = std::enable_if_t<std::is_floating_point<T>::value>>
     void rebinYBy(unsigned int n, size_t begin=1, size_t end=UINT_MAX) {
       static_cast<Derived*>(this)->template rebinBy<1>(n, begin, end);
     }
 
+    /// @brief Rebin to the given list of bin edges
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT, typename = std::enable_if_t<std::is_floating_point<T>::value>>
     void rebinYTo(const std::vector<double>& newedges) {
       static_cast<Derived*>(this)->template rebinTo<1>(newedges);
     }
 
+    /// @brief Overloaded alias for rebinYBy
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT, typename = std::enable_if_t<std::is_floating_point<T>::value>>
     void rebinY(unsigned int n, size_t begin=1, size_t end=UINT_MAX) {
       static_cast<Derived*>(this)->template rebinBy<1>(n, begin, end);
     }
 
+    /// @brief Overloaded alias for rebinYTo
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT, typename = std::enable_if_t<std::is_floating_point<T>::value>>
     void rebinY(const std::vector<double>& newedges) {
       static_cast<Derived*>(this)->template rebinTo<1>(newedges);
     }
@@ -165,6 +257,11 @@ namespace YODA {
     /// @name Whole histo data
     /// @{
 
+    /// @brief List of mean values on Y axis
+    std::vector<double> yMeans(const bool includeOverflows=true) const noexcept {
+      return static_cast<const Derived*>(this)->means(1, includeOverflows);
+    }
+
     /// @brief Calculate the mean on Y axis
     double yMean(const bool includeOverflows=true) const noexcept {
       return static_cast<const Derived*>(this)->mean(1, includeOverflows);
@@ -190,6 +287,8 @@ namespace YODA {
       return static_cast<const Derived*>(this)->rms(1, includeOverflows);
     }
 
+    /// @}
+
   };
 
 
@@ -227,18 +326,61 @@ namespace YODA {
       return static_cast<const Derived*>(this)->template widths<2>(includeOverflows);
     }
 
+    /// @brief All mins on Z axis
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT>
+    std::enable_if_t<std::is_floating_point<T>::value, std::vector<T>>
+    zMins(const bool includeOverflows = false) const {
+      return static_cast<const Derived*>(this)->template mins<2>(includeOverflows);
+    }
+
+    /// @brief All maxs on Z axis
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT>
+    std::enable_if_t<std::is_floating_point<T>::value, std::vector<T>>
+    zMaxs(const bool includeOverflows = false) const {
+      return static_cast<const Derived*>(this)->template maxs<2>(includeOverflows);
+    }
+
+    /// @brief All mids on Z axis
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT>
+    std::enable_if_t<std::is_floating_point<T>::value, std::vector<T>>
+    zMids(const bool includeOverflows = false) const {
+      return static_cast<const Derived*>(this)->template mids<2>(includeOverflows);
+    }
+
+    /// @brief Merge every group of @a n bins, from start to end inclusive
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT, typename = std::enable_if_t<std::is_floating_point<T>::value>>
     void rebinZBy(unsigned int n, size_t begin=1, size_t end=UINT_MAX) {
       static_cast<Derived*>(this)->template rebinBy<2>(n, begin, end);
     }
 
+    /// @brief Rebin to the given list of bin edges
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT, typename = std::enable_if_t<std::is_floating_point<T>::value>>
     void rebinZTo(const std::vector<double>& newedges) {
       static_cast<Derived*>(this)->template rebinTo<2>(newedges);
     }
 
+    /// @brief Overloaded alias for rebinZBy
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT, typename = std::enable_if_t<std::is_floating_point<T>::value>>
     void rebinZ(unsigned int n, size_t begin=1, size_t end=UINT_MAX) {
       static_cast<Derived*>(this)->template rebinBy<2>(n, begin, end);
     }
 
+    /// @brief Overloaded alias for rebinZTo
+    ///
+    /// @note Only supported for continuous axes
+    template <class T = EdgeT, typename = std::enable_if_t<std::is_floating_point<T>::value>>
     void rebinZ(const std::vector<double>& newedges) {
       static_cast<Derived*>(this)->template rebinTo<2>(newedges);
     }
@@ -254,6 +396,11 @@ namespace YODA {
     /// @name Whole histo data
     /// @{
 
+    /// @brief List of mean values on Z axis
+    std::vector<double> zMeans(const bool includeOverflows=true) const noexcept {
+      return static_cast<const Derived*>(this)->means(2, includeOverflows);
+    }
+
     /// @brief Calculate the mean on Z axis
     double zMean(const bool includeOverflows=true) const noexcept {
       return static_cast<const Derived*>(this)->mean(2, includeOverflows);
