@@ -10,6 +10,7 @@
 
 namespace YODA {
 
+
   /// @name Mixin of convenience methods using CRTP
   /// @{
 
@@ -82,7 +83,7 @@ namespace YODA {
     }
 
     /// Set the x errors
-    void setXErrs(std::pair<double,double> errs) {
+    void setXErrs(const std::pair<double,double>& errs) {
       static_cast<Derived*>(this)->setErrs(0, errs);
     }
 
@@ -115,14 +116,14 @@ namespace YODA {
     }
 
     /// Set x value and asymmetric error
-    void setX(double x, std::pair<double,double>& ex) {
+    void setX(double x, const std::pair<double,double>& ex) {
       setX(x);
       setXErrs(ex);
     }
 
     /// @}
 
-    // @name Manipulations
+    /// @name Manipulations
     /// @{
 
     /// Scaling of x axis
@@ -222,7 +223,7 @@ namespace YODA {
     }
 
     /// Set the y errors
-    void setYErrs(std::pair<double,double> errs) {
+    void setYErrs(const std::pair<double,double>& errs) {
       static_cast<Derived*>(this)->setErrs(1, errs);
     }
 
@@ -254,14 +255,14 @@ namespace YODA {
     }
 
     /// Set y value and asymmetric error
-    void setY(double y, std::pair<double,double>& ey) {
+    void setY(double y, const std::pair<double,double>& ey) {
       setY(y);
       setYErrs(ey);
     }
 
     /// @}
 
-    // @name Manipulations
+    /// @name Manipulations
     /// @{
 
     /// Scaling of y axis
@@ -352,7 +353,7 @@ namespace YODA {
     }
 
     /// Set the z errors
-    void setZErrs(std::pair<double,double> errs) {
+    void setZErrs(const std::pair<double,double>& errs) {
       static_cast<Derived*>(this)->setErrs(2, errs);
     }
 
@@ -384,14 +385,14 @@ namespace YODA {
     }
 
     /// Set z value and asymmetric error
-    void setZ(double z, std::pair<double,double>& ez) {
+    void setZ(double z, const std::pair<double,double>& ez) {
       setZ(z);
       setZErrs(ez);
     }
 
     /// @}
 
-    // @name Manipulations
+    /// @name Manipulations
     /// @{
 
     /// Scaling of z axis
