@@ -33,10 +33,7 @@ def mkCurves2D(aos_dict, plot_ref=True, error_bars=True, colors=[],
     line_properties = LineProperties(colors, line_styles)
 
     # Define useful variables
-    xpoints   = 0.5*(aos[0].xMins() + aos[0].xMaxs())
     xedges    = np.append(aos[0].xMins(), max(aos[0].xMaxs()))
-    ref_xvals = aos[0].xVals()
-    ref_xerrs = aos[0].xErrs()
     ypoints   = 0.5*(aos[0].yMins() + aos[0].yMaxs())
     ref_yvals = aos[0].yVals()
     ref_yerrs = aos[0].yErrs()
@@ -45,50 +42,31 @@ def mkCurves2D(aos_dict, plot_ref=True, error_bars=True, colors=[],
     ref_zvals = aos[0].zVals()
     ref_zerrs = aos[0].zErrs()
     data.add(f"import numpy as np",
-             f"from numpy import nan, inf",
-             f"xpoints = {[val for val in xpoints]}",
-             f"xedges  = {[val for val in xedges]}",
-             f"xmins   = {[val for val in aos[0].xMins()]}",
-             f"xmaxs   = {[val for val in aos[0].xMaxs()]}",
-             f"xerrs = [",
+             f"from numpy import nan, inf\n")
+
+    writeArray(data, 'xpoints', aos[0].xVals())
+    writeArray(data, 'xmins',   aos[0].xMins())
+    writeArray(data, 'xmaxs',   aos[0].xMaxs())
+    data.add(f"xerrs = [",
              f"  [abs(xpoints[i] - xmins[i]) for i in range(len(xpoints))],",
              f"  [abs(xmaxs[i] - xpoints[i]) for i in range(len(xpoints))]",
-             f"]")
-    data.newline()
+             f"]\n")
 
-    data.add(f"ref_xvals     = {[val for val in ref_xvals]}",
-             f"ref_xerrminus = {[err[0] for err in ref_xerrs]}",
-             f"ref_xerrplus  = {[err[1] for err in ref_xerrs]}",
-             f"ref_xerrs     = [ref_xerrminus, ref_xerrplus]")
-    data.newline()
-
-    data.add(f"ypoints   = {[val for val in ypoints]}",
-             f"ymins     = {[val for val in aos[0].yMins()]}",
-             f"ymaxs     = {[val for val in aos[0].yMaxs()]}",
-             f"yerrs = [",
+    writeArray(data, 'ypoints', aos[0].yVals())
+    writeArray(data, 'ymins',   aos[0].yMins())
+    writeArray(data, 'ymaxs',   aos[0].yMaxs())
+    data.add(f"yerrs = [",
              f"  [abs(ypoints[i] - ymins[i]) for i in range(len(ypoints))],",
              f"  [abs(ymaxs[i] - ypoints[i]) for i in range(len(ypoints))]",
-             f"]")
-    data.newline()
-
-    data.add(f"ref_yvals     = {[val for val in ref_yvals]}",
-             f"ref_yerrminus = {[err[0] for err in ref_yerrs]}",
-             f"ref_yerrplus  = {[err[1] for err in ref_yerrs]}",
-             f"ref_yerrs     = [ref_yerrminus, ref_yerrplus]")
-    data.newline()
-
-    data.add(f"zpoints   = {[val for val in zpoints]}",
-             f"zedges    = {[val for val in zedges]}",
-             f"zmins     = {[val for val in aos[0].zMins()]}",
-             f"zmaxs     = {[val for val in aos[0].zMaxs()]}")
-    data.newline()
-
-    data.add(f"ref_zvals     = {[val for val in ref_zvals]}",
-             f"ref_zerrminus = {[err[0] for err in ref_zerrs]}",
-             f"ref_zerrplus  = {[err[1] for err in ref_zerrs]}",
-             f"ref_zerrs     = [ref_zerrminus, ref_zerrplus]")
-    data.newline()
+             f"]\n")
 
+    writeArray(data, 'zpoints', aos[0].zVals())
+    writeArray(data, 'zmins',   aos[0].zMins())
+    writeArray(data, 'zmaxs',   aos[0].zMaxs())
+    data.add(f"zerrs = [",
+             f"  [abs(zpoints[i] - zmins[i]) for i in range(len(zpoints))],",
+             f"  [abs(zmaxs[i] - zpoints[i]) for i in range(len(zpoints))]",
+             f"]\n")
 
     # Plot the reference histogram data
     cmd.add("legend_handles = dict() # keep track of handles for the legend")
@@ -101,6 +79,7 @@ def mkCurves2D(aos_dict, plot_ref=True, error_bars=True, colors=[],
     #     plt_cntr = True
     colormap = kwargs['colormap'] if 'colormap' in kwargs else 'cividis'
 
+    transposeZ = int(aos[0].annotation('YODA1_ZVAL_LAYOUT', 0))
     if plot_ref:
         #suff = ",\n                    norm=mpl.colors.LogNorm())" \
         #suff = ",\n                    locator=mpl.ticker.LogLocator())" \
@@ -110,9 +89,11 @@ def mkCurves2D(aos_dict, plot_ref=True, error_bars=True, colors=[],
                 f"cmap = '{colormap}'", # TODO This needs to be configurable from the outside
                 f"xbin_cent = np.unique(dataf['xpoints'])",
                 f"ybin_cent = np.unique(dataf['ypoints'])",
-                f"X, Y = np.meshgrid(xbin_cent, ybin_cent)",
-                f"Z = np.array(dataf['zpoints']).reshape(X.shape[::-1])",
-                f"pc = ax.pcolormesh(X, Y, Z.T, cmap=cmap, shading='auto',",
+                f"X, Y = np.meshgrid(xbin_cent, ybin_cent)")
+        xshapestr = 'X.shape[::-1]' if transposeZ else 'X.shape'
+        zvalstr = 'Z.T' if transposeZ else 'Z'
+        cmd.add(f"Z = np.array(dataf['zpoints']).reshape({xshapestr})",
+                f"pc = ax.pcolormesh(X, Y, {zvalstr}, cmap=cmap, shading='auto',",
                 f"                   vmin=zLims[0], vmax=zLims[1]"+suff,
                 f"cbar = fig.colorbar(pc, orientation='vertical', ax=ax, pad=0.01)",#+suff,
                 f"cbar.set_label(ax_zLabel)")
@@ -120,7 +101,8 @@ def mkCurves2D(aos_dict, plot_ref=True, error_bars=True, colors=[],
     #
     c_zvals, c_zerrs, c_zups, c_zdowns, c_styles = {}, {}, {}, {}, {}
     if contourlevel is not None:
-        cmd.add(f"base_contour = ax.contour(X, Y, zvals.T, levels={contourlevel},",
+        zvalstr = 'zvals.T' if int(aos[0].annotation('transposeZ', 0)) else 'zvals'
+        cmd.add(f"base_contour = ax.contour(X, Y, {zvalstr}, levels={contourlevel},",
                 f"                          linestyles='--', alpha=0.6, linewidths=2,",
                 f"                          colors='black', zorder=2)",
                 f"legend_handles['ref'] = base_contour")
@@ -138,22 +120,6 @@ def mkCurves2D(aos_dict, plot_ref=True, error_bars=True, colors=[],
             c_zdowns[f'c{i}'] = [err[0] for err in ao.zErrs()]
             c_styles[f'c{i}'] = {'color' : f'colors[{colidx}]', 'linestyle' : linestyle, 'zorder' : zorder}
 
-    # write dictionary of labels + yvalues to iterate over in executable python script
-    # TODO What is this meant to be? Another z-error? We already added them?
-    data.add("zvals = {")
-    for label, zhists in c_zvals.items():
-        data.add(f"  '{label}' : {[val for val in zvals]},")
-    data.add("}", "zerrs = {")
-    for label, zrrs in c_zerrs.items():
-        data.add(f"  '{label}' : {[val for val in zerrs]},")
-    data.add("}", "zups = {")
-    for label, zups in c_zups.items():
-        data.add(f"  '{label}' : {[val for val in zups]},")
-    data.add("}", "z_down = {")
-    for label, zdowns in c_zdowns.items():
-        data.add(f"  '{label}' : {[val for val in zdowns]},")
-    data.add("}")
-
     if c_styles:
         cmd.add("# style options for curves",
                 "# starts at zorder>=5 to draw curve on top of legend")
@@ -172,10 +138,12 @@ def mkCurves2D(aos_dict, plot_ref=True, error_bars=True, colors=[],
             else:
                 cmd.add("}}")
 
+        xshapestr = 'X.shape[::-1]' if transposeZ else 'X.shape'
+        zvalstr = 'temp_zvals.T' if transposeZ else 'temp_zvals'
         cmd.add("# curve from input yoda files in main panel",
                 f"for label in dataf['zerrs'].keys():",
-                f"    temp_zvals = np.array(dataf['c_zvals'][label]).reshape(X.shape[::-1])",
-                f"    tmp_contour = ax.contour(X, Y, temp_zvals,",
+                f"    temp_zvals = np.array(dataf['c_zvals'][label]).reshape({xshapestr})",
+                f"    tmp_contour = ax.contour(X, Y, {zvalstr},",
                 f"                             levels={contourlevel},",
                 f"                             linestyle=c_styles[label]['linestyle'],",
                 f"                             linewidths=2, colors=c_styles[label]['color'],",
@@ -236,9 +204,10 @@ def mkCurves1D(aos, ratio_panels, error_bars=True, variation_dict=None,
         # save numerical values in dictionaries, write to file later
         # For "edges" we prepend the first element to be able to
         # draw a line like a rectangular histogram on canvas.
-        yvals[ k] = ao_yvals
-        xdowns[k], xups[k] = np.abs(ao_xerrs)
-        ydowns[k], yups[k] = np.abs(ao_yerrs)
+        if ao.annotation('MainPanel', True):
+            yvals[ k] = ao_yvals
+            xdowns[k], xups[k] = np.abs(ao_xerrs)
+            ydowns[k], yups[k] = np.abs(ao_yerrs)
 
         # check if the AO needs an uncertainty band
         if str(ao.annotation('ErrorBand', '0')) != '0':
@@ -317,6 +286,7 @@ def mkCurves1D(aos, ratio_panels, error_bars=True, variation_dict=None,
             histstyle = ao.annotation(pre+'ConnectBins', styles[k]['histstyle'] if pre else 1)
             lstyle = ao.annotation(pre+'LineStyle', ao.annotation('LineStyle', linestyle))
             lwidth = ao.annotation(pre+'LineWidth', ao.annotation('LineWidth', 1))
+            lopacity = ao.annotation(pre+'LineOpacity', ao.annotation('LineOpacity', 1.0))
             mstyle = ao.annotation(pre+'MarkerStyle', styles[k]['marker'] if pre else 'none' if histstyle else 'o')
             msize = ao.annotation(pre+'MarkerSize', ao.annotation('MarkerSize', 2))
             capsize = ao.annotation(pre+'ErrorCapSize', ao.annotation('ErrorCapSize', 0.0))
@@ -326,6 +296,7 @@ def mkCurves1D(aos, ratio_panels, error_bars=True, variation_dict=None,
             dstyle = None if ao.annotation(pre+'ConnectMarkers', ao.annotation('ConnectMarkers', 0)) else 'steps-pre'
             styles[k].update({
                 rlabel+'linestyle'   : lstyle,
+                rlabel+'lineopacity' : lopacity,
                 rlabel+'linewidth'   : lwidth,
                 rlabel+'marker'      : mstyle,
                 rlabel+'markersize'  : msize,
@@ -360,18 +331,19 @@ def mkCurves1D(aos, ratio_panels, error_bars=True, variation_dict=None,
              "from numpy import nan, inf")
     data.newline()
     data.add("add_legend_handle = [",
-             ",\n".join([ f"    '{k}'" for k,v in aos.items() if v.annotation('Title', None) ]),
+             ",\n".join([ f"  '{k}'" for k,v in aos.items() if v.annotation('Title', None) ]),
              "]")
     data.newline()
     writeLists(data, 'xpoints', xpoints)
-    writeLists(data, 'xedges',  xedges)
+    writeLists(data, 'xedges', xedges)
+
     data.add(f"ref_xerrs = [")
     data.add(f"  [abs(xpoints['{ref_label}'][i]   - xedges['{ref_label}'][i])"
              + f" for i in range(len(xpoints['{ref_label}']))],")
     data.add(f"  [abs(xedges['{ref_label}'][i+1] - xpoints['{ref_label}'][i])"
              + f" for i in range(len(xpoints['{ref_label}']))]")
-    data.add(f"]")
-    data.newline()
+    data.add(f"]\n")
+
     writeLists(data, 'yvals',  yvals)
     writeLists(data, 'xerrs', xups, xdowns)
     writeLists(data, 'yerrs', yups, ydowns)
@@ -415,6 +387,7 @@ def mkCurves1D(aos, ratio_panels, error_bars=True, variation_dict=None,
             f"        tmp, = ax.plot(xpos, ypos,",
             f"                       color=styles[label]['color'],",
             f"                       linestyle=styles[label]['linestyle'],",
+            f"                       alpha=styles[label]['lineopacity'],",
             f"                       linewidth=styles[label]['linewidth'],",
             f"                       drawstyle=styles[label]['drawstyle'], solid_joinstyle='miter',",
             f"                       zorder=styles[label]['zorder'], label=label)",
@@ -422,6 +395,7 @@ def mkCurves1D(aos, ratio_panels, error_bars=True, variation_dict=None,
             f"                      xerr=np.array(dataf['xerrs'][label])*styles[label]['xerrorbars'],",
             f"                      yerr=np.array(dataf['yerrs'][label])*styles[label]['yerrorbars'],",
             f"                      fmt=styles[label]['marker'], capsize=styles[label]['capsize'],",
+            f"                      alpha=styles[label]['lineopacity'],",
             f"                      markersize=styles[label]['markersize'],",
             f"                      ecolor=styles[label]['color'],",
             f"                      color=styles[label]['color'], zorder=styles[label]['zorder'])",
@@ -523,12 +497,14 @@ def mkCurves1D(aos, ratio_panels, error_bars=True, variation_dict=None,
                 f"                       color=styles[label]['color'],",
                 f"                       linewidth=styles[label]['linewidth'],",
                 f"                       linestyle=styles[label]['{prefix}_linestyle'],",
+                f"                       alpha=styles[label]['{prefix}_lineopacity'],",
                 f"                       drawstyle=styles[label]['{prefix}_drawstyle'], zorder=styles[label]['zorder'],",
                 f"                       solid_joinstyle='miter')",
                 f"    tmp = {axlabel}.errorbar(dataf['xpoints']['{ref_label}'], yvals,",
                 f"                             xerr=np.array(dataf['ref_xerrs'])*styles[label]['{prefix}_xerrorbars'],",
                 f"                             yerr=np.array(dataf['{prefix}_yerrs'][label])*styles[label]['{prefix}_yerrorbars'],",
                 f"                             fmt=styles[label]['{prefix}_marker'], capsize=styles[label]['{prefix}_capsize'],",
+                f"                             alpha=styles[label]['{prefix}_lineopacity'],",
                 f"                             markersize=styles[label]['{prefix}_markersize'],",
                 f"                             ecolor=styles[label]['color'],",
                 f"                             color=styles[label]['color'])",
@@ -567,19 +543,40 @@ def mkCurves1D(aos, ratio_panels, error_bars=True, variation_dict=None,
     return cmd.get(), data.get()
 
 
-def writeLists(cmd, val_type, val_dict, val_alt = None):
-    """Take a label and dictionary as input,
-       return as a formatted string."""
-    cmd.add(f"""{val_type} = {{""")
-    for label, vals in val_dict.items():
-        if val_alt is None:
-            cmd.add(f"""    '{label}' : {[float(val) for val in vals]},""")
-        else:
-            cmd.add(f"""    '{label}' : [""",
-                    f"""        {[float(val) for val in vals]},""",
-                    f"""        {[float(val) for val in val_alt[label]]},""",
-                    f"""    ],""")
-    cmd.add("}")
+def writeArray(cmd, label, arr):
+    """Take a label and array as input, return as a formatted string."""
+    np.set_printoptions(formatter={'float' : '{:.6e}'.format})
+    indent = ' ' * (len(label) + 3)
+    vals = np.array2string(arr, separator=", ").replace("\n", "\n"+indent)
+    cmd.add(f"{label} = {vals}")
+    cmd.newline()
+
+
+def writeLists(cmd, label, *args):
+    """Take a label and dictionary as input, return as a formatted string."""
+    np.set_printoptions(formatter={'float' : '{:.6e}'.format})
+    if len(args) == 1:
+        width = max(len(k) for k in args[0]) if len(args[0]) else 0
+        indent = ' ' * (width + 9)
+        cmd.add(f"{label} = {{")
+        for k,v in args[0].items():
+            name = f"'{k}'"
+            vals = np.array2string(v, separator=", ").replace("\n", "\n"+indent)
+            cmd.add(f"    {name:>{width+2}} : {vals},")
+    else:
+        ups, dns = args
+        width = max(len(k) for k in ups) if len(ups) else 0
+        indent = ' ' * (width + 12)
+        cmd.add(f"{label} = {{")
+        for k,v in ups.items():
+            name = f"'{k}'"
+            upvals = np.array2string(v, separator=", ").replace("\n", "\n"+indent)
+            dnvals = np.array2string(dns[k], separator=", ").replace("\n", "\n"+indent)
+            cmd.add(f"    {name:>{width+2}} : [",
+                    indent+f"{upvals},",
+                    indent+f"{dnvals},",
+                    indent[:-3]+f"],")
+    cmd.add("}\n")
 
 
 class LineProperties:
