@@ -14,6 +14,8 @@ import numpy as np
 
 RE_PATTERN_PATH = re.compile(r'PATH\[(.+?)\]')
 RE_PATTERN_NAME = re.compile(r'NAME\[(.+?)\]')
+RE_PATTERN_OPTS = re.compile(r':([^:/=]+=[^:/=]+)')
+RE_PATTERN_OVAL = re.compile(r'\w+=(.+)')
 
 
 def setCanvas(cmd, fig_dims, margins, nRatios = 0, fig_specs = None):
@@ -90,6 +92,7 @@ def mkPlottingScript1D(hist_data, hist_features, yaml_dicts, outdir, plot_name,
 
     # check if user supplied regex-based label customisation
     re_captures = []
+    regex_subs = plot_features.get('PlotRegexSubs', {})
     for item in plot_features.get('PlotRegexes', []):
         for match in RE_PATTERN_NAME.findall(item):
             sub = re.findall(match, list(hist_data.values())[0].name())
@@ -97,7 +100,13 @@ def mkPlottingScript1D(hist_data, hist_features, yaml_dicts, outdir, plot_name,
         for match in RE_PATTERN_PATH.findall(item):
             sub = re.findall(match, list(hist_data.values())[0].path())
             if sub:  re_captures.append(sub[0])
-    _apply_regexes(plot_features, re_captures, plot_features.get('PlotRegexSubs', {}))
+    _apply_regexes(plot_features, re_captures, regex_subs)
+
+    # check if user supplied regex-based legend-entry substitutions
+    for i, ao in enumerate(hist_data.values()):
+        opt_captures = [ opt for optstr in RE_PATTERN_OPTS.findall(ao.path())
+                             for opt in RE_PATTERN_OVAL.findall(optstr.strip(':')) ]
+        hist_features[i]['Title'] = applyRegexes(hist_features[i].get('Title', ''), opt_captures, regex_subs)
 
     # adjust font sizes if necessary:
     for key, val in {
@@ -135,12 +144,12 @@ def mkPlottingScript1D(hist_data, hist_features, yaml_dicts, outdir, plot_name,
     nOverflows = [ h.annotation('nOverflows', 0) for h in hist_data.values() ]
     # keeping overflows requires user to have set IncludeOverflows=1 and all objects having two overflows
     hasOverflows = set(nOverflows).pop() == 2 if int(plot_features.get('IncludeOverflows', '0')) else False
-    xmin = plot_features.get('XMin', min([min(h.xMins()[1:-1] \
+    xmin = float(plot_features.get('XMin', min([min(h.xMins()[1:-1] \
                                           if nOverflows[i] == 2 and int(plot_features.get('IncludeOverflows', '0')) else \
-                                          h.xMins()) for i,h in enumerate(hist_data.values())]))
-    xmax = plot_features.get('XMax', max([max(h.xMaxs()[1:-1] \
+                                          h.xMins()) for i,h in enumerate(hist_data.values())])))
+    xmax = float(plot_features.get('XMax', max([max(h.xMaxs()[1:-1] \
                                           if nOverflows[i] == 2 and int(plot_features.get('IncludeOverflows', '0')) else \
-                                          h.xMaxs()) for i,h in enumerate(hist_data.values())]))
+                                          h.xMaxs()) for i,h in enumerate(hist_data.values())])))
     if ax_format['logx']:
         xmin = np.log10(xmin)
         xmax = np.log10(xmax)
@@ -247,6 +256,12 @@ def mkPlottingScript1D(hist_data, hist_features, yaml_dicts, outdir, plot_name,
                                        plot_features.get(f'{label}Anchor', anc),
                                        plot_features.get(f'{label}Align', al))
 
+        # Check for main-panel configs
+        if label == "DrawOnly":
+            toDraw = plot_features.get('DrawOnly', '').split()
+            for aoname, ao in hist_data.items():
+                ao.setAnnotation('MainPanel', aoname in toDraw)
+
         # Check for ratio-panel configs
         if not re.fullmatch(r"RatioPlot(\d+)?$", label):  continue
         if not plot_features.get(label, 0):  continue
@@ -265,8 +280,7 @@ def mkPlottingScript1D(hist_data, hist_features, yaml_dicts, outdir, plot_name,
                     ratio_panels[label] = [ rcurve ]
         elif default:
             ratio_panels[label] += list(hist_data.keys())[1:]
-        n = '0' if 't' == label[-1] else label[-1]
-        ax_format['ratio%s_logy' % n] = plot_features.get(label + 'LogY', 0)
+        ax_format[f'ratio{len(ratio_panels)-1}_logy'] = plot_features.get(label + 'LogY', 0)
     if not ratio_panels and plot_features.get('RatioPlot', 1):
         ## Unless user specifically asks not have ratio panel,
         ## have at least one by default
@@ -313,7 +327,7 @@ def mkPlottingScript1D(hist_data, hist_features, yaml_dicts, outdir, plot_name,
         for legName, (labels, title) in leg_titles.items():
             texLabels = 'r"' + '", r"'.join(labels) + '"' #< Use r-strings to be TeX friendly
             texTitle = 'r"' + title + '"'
-            cmd.add(f"    '{legName.lower()}' : ([ {texLabels} ], {texTitle}),")
+            cmd.add(f"  '{legName.lower()}' : ([ {texLabels} ], {texTitle}),")
         cmd.add("}")
 
 
@@ -382,9 +396,9 @@ def mkPlottingScript1D(hist_data, hist_features, yaml_dicts, outdir, plot_name,
     for i, (label,ao) in enumerate(hist_data.items()):
         # move command-line tags into annotations
         for pre in [''] + list(ratio_panels.keys()):
-            for base_tag in ['Title', 'LineStyle', 'LineWidth', 'MarkerStyle', 'MarkerSize',
-                             'ConnectBins', 'ConnectMarkers', 'FillColor', 'FillOpacity',
-                             'ErrorCapSize', 'ErrorBand', 'ErrorBandColor',
+            for base_tag in ['Title', 'LineStyle', 'LineWidth', 'LineOpacity', 'MarkerStyle',
+                             'MarkerSize', 'ConnectBins', 'ConnectMarkers', 'FillColor',
+                             'FillOpacity', 'ErrorCapSize', 'ErrorBand', 'ErrorBandColor',
                              'ErrorBandStyle', 'ErrorBandOpacity' ]:
                 tag = pre+base_tag
                 if tag in hist_features[i]:
@@ -457,6 +471,12 @@ def mkPlottingScript1D(hist_data, hist_features, yaml_dicts, outdir, plot_name,
             f"ax.set_xscale(ax_xScale)",
             f"ax.set_yscale(ax_yScale)")
 
+    for rid, key in enumerate(ratio_panels.keys()):
+        if deviation_modes[rid]:  continue
+        ratioName = f'ratio{rid}'
+        yscale = 'log' if ax_format[f'{ratioName}_logy'] else 'linear'
+        cmd.add(f"{ratioName}_ax.set_yscale('{yscale}')")
+
     ## Toggle x/y lims
     cmd.add("ax.set_xlim(xLims)")
     cmd.add("ax.set_ylim(yLims)")
@@ -555,9 +575,9 @@ def mkPlottingScript1D(hist_data, hist_features, yaml_dicts, outdir, plot_name,
                     f"ax.annotate(r'{overflow_label}', xy=(overflow_xpos, overflow_ypos),",
                     f"            ha='center', fontsize={overflow_size}, color='{overflow_color}')")
 
-    for key in ratio_panels.keys():
-        ratioName = 'ratio' + ('0' if 't' == key[-1] else key[-1])
-        if ax_format[ratioName + '_logy']:
+    for rid, key in enumerate(ratio_panels.keys()):
+        ratioName = f'ratio{rid}'
+        if ax_format[f'{ratioName}_logy']:
             cmd.add(f"{ratioName}_ax.yaxis.set_major_locator(mpl.ticker.LogLocator(base=10.0, numticks=np.inf))",
                     f"{ratioName}_ax.yaxis.set_minor_locator(mpl.ticker.LogLocator(",
                     f"                           base=10.0, subs=np.arange(0.1, 1, 0.1), numticks=np.inf))")
@@ -571,6 +591,28 @@ def mkPlottingScript1D(hist_data, hist_features, yaml_dicts, outdir, plot_name,
     if plot_features.get('DummyXaxis'):
         cmd.add("ax.tick_params(axis='x', which='both', bottom=False, top=False, labelbottom=False)")
 
+    # Loop over lines
+    for lb in [ k for k in plot_features if k.startswith('line_') ]:
+        lbName = lb.replace('line_', '')
+        lbSetup = plot_features[lb]
+        # Loop over panels
+        for i, key in enumerate(list(ratio_panels.keys()) + ['Plot']):
+            panelName = 'ax' if key == 'Plot' else 'ratio%d_ax' % i
+            xlocs = str(lbSetup.get(key+'XPos', '')).split()
+            ylocs = str(lbSetup.get(key+'YPos', '')).split()
+            lineopts = ''
+            val = lbSetup.get('LineColor', 'black')
+            if val:  lineopts += f', color="{val}"'
+            val = lbSetup.get('LineStyle', None)
+            if val:  lineopts += f', ls="{val}"'
+            val = lbSetup.get('LineWidth', None)
+            if val:  lineopts += f', lw={val}'
+            # TODO: add more formatting options?
+            for xpos in xlocs:
+                cmd.add(f'{panelName}.axvline(x={xpos}{lineopts})')
+            for ypos in ylocs:
+                cmd.add(f'{panelName}.axhline(y={ypos}{lineopts})')
+
     # Loop over text boxes
     for tb in [ k for k in plot_features if k.startswith('text_') ]:
         textBoxName = tb.replace('text_', '')
@@ -590,7 +632,7 @@ def mkPlottingScript1D(hist_data, hist_features, yaml_dicts, outdir, plot_name,
             if angle:
                 boxopts += f', rotation={angle}, rotation_mode="anchor"'
             # TODO: add more formatting options?
-            cmd.add(f"{panelName}.text({xpos}, {ypos}, '{txt}'{boxopts})")
+            cmd.add(f"{panelName}.text({xpos}, {ypos}, r'{txt}'{boxopts})")
 
     if len(ratio_panels.keys()):
         rpanels = ', '.join([ 'ratio%d_ax' % i for i in range(len(ratio_panels.keys())) ])
@@ -828,7 +870,7 @@ def process(yaml_file, plot_name, outdir = './', formats = ['pdf']):
                 hist_data[k].scale(hist_data[k].dim()-1, float(hist_dict['Scale']))
             if 'Rebin' in yaml_dicts['plot features']:
                 try:
-                    newao = putils.scatter_rebin(hist_data[k], yaml_dicts['plot features'].get('Rebin'))
+                    newao = putils.scatter_rebin(hist_data[k], int(yaml_dicts['plot features'].get('Rebin')))
                     hist_data[k] = newao
                 except:
                     print('WARNING - rebinning attempt failed!')
@@ -900,6 +942,10 @@ def _preprocess_text(yaml_dicts):
     for label in plot_features:
         if any(label.endswith(sub) for sub in ('Title', 'Label', 'CustomMajorTicks')):
             plot_features[label] = preprocess(plot_features[label])
+        if label.startswith('text_'):
+            for tlabel, tvalue in plot_features[label].items():
+                if tlabel.endswith('Text'):
+                    plot_features[label][tlabel] = preprocess(tvalue)
 
     for hist_setting in yaml_dicts['histograms'].values():
         if 'Title' in hist_setting:
