@@ -1,6 +1,6 @@
 import yoda
 import numpy as np
-import math
+import math, os, re
 
 
 def safeDiv(numer, denom):
@@ -71,11 +71,16 @@ def reshape(ref_vals, ref_edges, ao, force_rebin = False):
     """Helper method to reshape yvals and yerrs to match shape of reference curve.
        If the probe has fewer elements than the reference, pad using NaNs."""
     xprobe = ao.xVals()
+    # if the binning of a curve is finer than the reference curve
+    # and force_rebin = True, harmonise the binning:
     if force_rebin and xprobe.shape > ref_vals.shape:
         xedges = np.append(ao.xMins(), max(ao.xMaxs()))
         return rebinTo(xedges, ref_edges, ao.yVals(), transpose(ao.yErrs()))
-    if xprobe.shape >= ref_vals.shape:
+    # If force_rebin = False and the binning is finer or inconsistent, leave as is
+    if xprobe.shape >= ref_vals.shape or \
+       (not force_rebin and not len(np.intersect1d(xprobe, ref_vals, assume_unique=True))):
         return ao.yVals(), transpose(ao.xErrs()), transpose(ao.yErrs())
+    # if the binning is largely consistent, except for some missing elements, pad with nan
     return pad(xprobe, ref_vals, ao.yVals(), transpose(ao.xErrs()), transpose(ao.yErrs()))
 
 
@@ -102,7 +107,7 @@ def mkPlotFriendlyScatter(ao,includeOverflows=False,includeMaskedBins=True,error
     rtn = ao.mkScatter(ao.path(), errorPattern,
                        includeOverflows=includeOverflows,
                        includeMaskedBins=includeMaskedBins) if 'BinnedEstimate' in origT else \
-          ao.mkScatter(ao.path(), binwidthdiv=True, useFocus=False,
+          ao.mkScatter(ao.path(), divbyvol=True, usefocus=False,
                        includeOverflows=includeOverflows,
                        includeMaskedBins=includeMaskedBins) if 'Binned' in origT else \
           ao.mkScatter(ao.path(), errorPattern) if 'Estimate' in origT else ao.mkScatter(ao.path())
@@ -225,6 +230,7 @@ def legendDefaults(refAO, xlims, ylims, logx, logy):
                 xypos = (0.00,0.97)
         else: # mv legend below curve
             # ToDo: extend y-axis range?
+            anchor = anchor.replace('upper', 'lower')
             xypos = (1.00,0.03)
         return *xypos, anchor, align
     # split x-range into thirds
@@ -292,3 +298,14 @@ def adjustOverflows(aos, xlims, hasOverflows, modUnderflow, modOverflow):
             ao.point(ao.numPoints()-1).setXErrs(dx)
         elif hasOverflows:
             ao.rmPoint(ao.numPoints()-1)
+
+
+def load_plot_configs(filenames, aopath = None):
+    configs = {}
+    for fname in filenames:
+        if not os.access(fname, os.R_OK):  continue
+        with open(fname, 'r') as f:
+            for bname, block in yoda.util._parseyaml(f).items():
+                if aopath is None or re.match(bname, aopath):
+                    configs.update(block)
+    return configs
