@@ -35,5 +35,12 @@ int main() {
   // Scatter3D divided(first / second);
   // MSG_GREEN("PASS");
 
+  Histo2D* hptr = first.newclone();
+  if (hptr == nullptr) {
+    MSG_RED("FAIL");
+    return -1;
+  }
+  MSG_GREEN("PASS");
+
   return EXIT_SUCCESS;
 }
