@@ -46,5 +46,13 @@ int main() {
   }
   cout << "PASS" << endl;
 
+  cout << "Checking fill with coord group:          ";
+  h.fill(Histo2D::FillType{50.,50.}, 10);
+  if (h.binAt(50.,50.).sumW() != 10) {
+    cout << "FAIL" << endl;
+    return -1;
+  }
+  cout << "PASS" << endl;
+
   return EXIT_SUCCESS;
 }
