@@ -1,4 +1,4 @@
-#include "YODA/Profile1D.h"
+#include "YODA/Profile.h"
 #include "YODA/Utils/Formatting.h"
 
 using namespace YODA;
@@ -21,33 +21,41 @@ int main() {
 
 
   MSG_(PAD(70) << "Testing the fill of the underflow: ");
-  p.fill(-10,2,3);
-  if (p.underflow().xMean() != -10) {
+  p.fill(-10, 2, 3);
+  if (!fuzzyEquals(p.bin(0).mean(1), -10)) {
     MSG_RED("FAIL");
     return -1;
   }
-  if (p.underflow().yMean() != 2) {
+  if (p.bin(0).mean(1) != -10) {
     MSG_RED("FAIL");
     return -1;
   }
-  if (p.underflow().sumW() != 3 || p.underflow().sumW2() != 9) {
+  if (p.bin(0).mean(2) != 2) {
+    MSG_RED("FAIL");
+    return -1;
+  }
+  if (p.bin(0).sumW() != 3 || p.bin(0).sumW2() != 9) {
     MSG_RED("FAIL");
     return -1;
   }
   MSG_GREEN("PASS");
 
 
-  MSG_(PAD(70) << "Testing the fill of the underflow: ");
+  MSG_(PAD(70) << "Testing the fill of the overflow: ");
   p.fill(110,2,3);
-  if (p.overflow().xMean() != 110) {
+  if (!fuzzyEquals(p.bin(p.numBins()+1).mean(1), 110)) {
     MSG_RED("FAIL");
     return -1;
   }
-  if (p.overflow().yMean() != 2) {
+  if (p.bin(p.numBins()+1).mean(1) != 110) {
     MSG_RED("FAIL");
     return -1;
   }
-  if (p.overflow().sumW() != 3 || p.overflow().sumW2() != 9) {
+  if (p.bin(p.numBins()+1).mean(2) != 2) {
+    MSG_RED("FAIL");
+    return -1;
+  }
+  if (p.bin(p.numBins()+1).sumW() != 3 || p.bin(p.numBins()+1).sumW2() != 9) {
     MSG_RED("FAIL");
     return -1;
   }
