@@ -1,4 +1,4 @@
-#include "YODA/Profile1D.h"
+#include "YODA/Profile.h"
 #include "YODA/Utils/Formatting.h"
 
 using namespace YODA;
@@ -29,8 +29,8 @@ int main() {
   MSG_GREEN("PASS");
 
   MSG_(PAD(70) << "Merging the bins: ");
-  p.mergeBins(0,10);
-  if (p.bin(0).xMin() != 0 || p.bin(0).xMax() != 11){
+  p.mergeBins<0>({0, 10});
+  if (p.bin(0).xMin() != -std::numeric_limits<double>::infinity() || !fuzzyEquals(p.bin(0).xMax(), 10)) {
     MSG_RED("FAIL");
     return -1;
   }
@@ -41,7 +41,7 @@ int main() {
   MSG_GREEN("PASS");
 
   MSG_(PAD(70) << "Testing rebinning: ");
-  p.rebin(2);
+  p.rebin<0>(2);
   for (size_t i = 1; i < p.bins().size() - 1; ++i){
     if (2 != p.bin(i).xWidth()){
       MSG_RED("FAIL");
@@ -54,24 +54,6 @@ int main() {
   }
   MSG_GREEN("PASS");
 
-  MSG_(PAD(70) << "Trying to add a bin (first method): ");
-  p.addBin(110, 120);
-  if (p.numBins() != 46){
-    MSG_RED("FAIL");
-    return -1;
-  }
-  MSG_GREEN("PASS");
-
-  MSG_(PAD(70) << "Trying to add a bin (second method): ");
-  vector<double> test;
-  test.push_back(120); test.push_back( 140); test.push_back(145);
-  p.addBins(test);
-  if (p.numBins() != 48){
-    MSG_RED("FAIL");
-    return -1;
-  }
-  MSG_GREEN("PASS");
-
   // MSG_(PAD(70) << "Trying to add a bin (third method): ");
   // vector<pair<double,double> > test2;
   // test2.push_back(make_pair(180,190));
