@@ -315,6 +315,11 @@ auto testTypeReductions() {
   Estimate1D e2 = p1.mkEstimate();
   assert(e1 == e2);
 
+  Estimate1D e3 = h1.mkEstimate(/*path=*/"",
+                                /*source=*/"",
+                                /*divbyvol=*/true,
+                                /*overflowWidth=*/1.0);
+
   BinnedHisto2D<int,std::string> h2({1,2,3}, {"A", "B", "C"});
   BinnedEstimate2D<int,std::string> e2D = h2.mkEstimate();
   std::vector<BinnedEstimate1D<std::string>> e1D_s = h2.mkEstimates<0>(); // slice along int axis
