@@ -1,7 +1,5 @@
-#include "YODA/Histo1D.h"
-#include "YODA/WriterAIDA.h"
+#include "YODA/Histo.h"
 #include "YODA/WriterYODA.h"
-#include "YODA/ReaderAIDA.h"
 #include "YODA/ReaderYODA.h"
 #include <cmath>
 #include <vector>
@@ -29,11 +27,11 @@ int main() {
   /// that the under/overflows are working
 
   /// Write one histo out to stdout, with various scalings
-  WriterYODA::write(cout, h1);
+  //WriterYODA::write(cout, h1);
   h1.scaleW(0.5);
-  WriterYODA::write(cout, h1);
+  //WriterYODA::write(cout, h1);
   h1.scaleW(2);
-  WriterYODA::write(cout, h1);
+  //WriterYODA::write(cout, h1);
 
   /// Write two histos out to file
   vector<AnalysisObject*> hs;
@@ -41,25 +39,11 @@ int main() {
   hs.push_back(&h2);
   // WriterYODA::write("test.yoda", hs);
   // WriterYODA::write("test.yoda", hs.begin(), hs.end());
-  WriterAIDA::write("test.aida", hs);
-  WriterAIDA::write("test.aida", hs.begin(), hs.end());
 
-  vector<AnalysisObject*> hs2 = ReaderAIDA::create().read("test.aida");
-  cout << hs2.size() << endl;
-  assert(hs2.size() == 2);
-  for (vector<AnalysisObject*>::const_iterator i = hs2.begin(); i != hs2.end(); ++i) {
-    cout << (*i)->type() << endl;
-    if ((*i)->type() == "Histo1D") {
-      (*i)->path();
-    }
-  }
-
-  const string testsrcdir = YODA_TESTS_SRC;
-  cout << "Reading file from tests src dir = " << testsrcdir << endl;
-  vector<AnalysisObject*> hs3 = ReaderYODA::create().read(testsrcdir + "/test.yoda");
+  vector<AnalysisObject*> hs3 = ReaderYODA::create().read("test.yoda");
   for (vector<AnalysisObject*>::const_iterator i = hs3.begin(); i != hs3.end(); ++i) {
     cout << (*i)->type() << endl;
-    YODA::WriterYODA::write(std::cout, (**i));
+    //YODA::WriterYODA::write(std::cout, (**i));
     if ((*i)->type() == "Histo1D") {
       (*i)->path();
     }
