@@ -14,9 +14,9 @@ NUM_SAMPLES = 1000
 for i in range(NUM_SAMPLES):
     exp = - (i-NUM_SAMPLES/2)**2 / float(NUM_SAMPLES/4)
     val = 2.718 ** exp
-    h1.fill(val);
-    h2.fill(val);
-    h3.fill(val);
+    h1.fill(val)
+    h2.fill(val)
+    h3.fill(val)
 print(h1.xMean(), "+-", h1.xStdDev())
 print(h1)
 print(h1.bins())
