@@ -1,14 +1,8 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
 from io import BytesIO, StringIO
+import sys, os
 
-import sys
-if sys.version_info <= (3,0):
-    # workaround for:
-    #   TypeError: initial_value must be unicode or None, not str
-    from StringIO import StringIO
-
-import os
 TESTSRCDIR = os.environ.get("YODA_TESTS_SRC", ".")
 def testsrcpath(fname):
     return os.path.join(TESTSRCDIR, fname)
